Files
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

141 lines
4.6 KiB
C++

// MIT License
//
// Copyright (c) 2023-2026 Advanced Micro Devices, Inc. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#include <rocprofiler-sdk-roctx/roctx.h>
#include <hip/hip_runtime.h>
#include <stdio.h>
#include <stdlib.h>
#define WIDTH 1024
#define NUM (WIDTH * WIDTH)
#define THREADS_PER_BLOCK_X 4
#define THREADS_PER_BLOCK_Y 4
template <typename T>
void
check(T result, char const* const func, const char* const file, int const line)
{
if(result)
{
fprintf(stderr,
"Hip error at %s:%d code=%d(%s) \"%s\" \n",
file,
line,
static_cast<unsigned int>(result),
hipGetErrorName(result),
func);
exit(EXIT_FAILURE);
}
}
#define checkHipErrors(val) check((val), #val, __FILE__, __LINE__)
// Kernel A: launched BEFORE roctxProfilerResume — should NOT appear in ATT output
__global__ void
before_trace_kernel(float* out, const float* in, const int width)
{
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
out[y * width + x] = in[x * width + y] + 1.0f;
}
// Kernel B: launched AFTER roctxProfilerResume — should appear in ATT output
__global__ void
traced_kernel_first(float* out, const float* in, const int width)
{
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
out[y * width + x] = in[x * width + y] * 2.0f;
}
// Kernel C: launched AFTER roctxProfilerResume — should appear in ATT output
__global__ void
traced_kernel_second(float* out, const float* in, const int width)
{
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
out[y * width + x] = in[x * width + y] * 3.0f;
}
// Kernel D: launched AFTER roctxProfilerPause — should NOT appear in ATT output
__global__ void
after_trace_kernel(float* out, const float* in, const int width)
{
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
out[y * width + x] = in[x * width + y] - 1.0f;
}
int
main()
{
float* gpuIn = nullptr;
float* gpuOut = nullptr;
float* hostIn = nullptr;
hostIn = (float*) malloc(NUM * sizeof(float));
for(int i = 0; i < NUM; i++)
hostIn[i] = (float) i * 10.0f;
checkHipErrors(hipMalloc(&gpuIn, NUM * sizeof(float)));
checkHipErrors(hipMalloc(&gpuOut, NUM * sizeof(float)));
checkHipErrors(hipMemcpy(gpuIn, hostIn, NUM * sizeof(float), hipMemcpyHostToDevice));
dim3 grid(WIDTH / THREADS_PER_BLOCK_X, WIDTH / THREADS_PER_BLOCK_Y);
dim3 block(THREADS_PER_BLOCK_X, THREADS_PER_BLOCK_Y);
// Kernel A: before tracing is enabled (all contexts start stopped
// because --att-marker-trace implies --selected-regions)
hipLaunchKernelGGL(before_trace_kernel, grid, block, 0, 0, gpuOut, gpuIn, WIDTH);
checkHipErrors(hipDeviceSynchronize());
// Start thread trace collection
roctxProfilerResume(0);
// Kernel B: traced
hipLaunchKernelGGL(traced_kernel_first, grid, block, 0, 0, gpuOut, gpuIn, WIDTH);
// Kernel C: traced
hipLaunchKernelGGL(traced_kernel_second, grid, block, 0, 0, gpuOut, gpuIn, WIDTH);
// Synchronize before stopping to ensure GPU work completes
checkHipErrors(hipDeviceSynchronize());
// Stop thread trace collection
roctxProfilerPause(0);
// Kernel D: after tracing is disabled
hipLaunchKernelGGL(after_trace_kernel, grid, block, 0, 0, gpuOut, gpuIn, WIDTH);
checkHipErrors(hipDeviceSynchronize());
checkHipErrors(hipFree(gpuIn));
checkHipErrors(hipFree(gpuOut));
free(hostIn);
return 0;
}